@@ -88,7 +88,8 @@ class NxPyDocs():
         fg='green')
 
     def yaml_file(self, parsed_json):
-        clean_yaml = yaml.dump(json.loads(json.dumps(parsed_json.replace("!!python/unicode",""),indent=4, sort_keys=True)), default_flow_style=False)
+        dirty_yaml = yaml.dump(json.loads(json.dumps(parsed_json,indent=4, sort_keys=True)), default_flow_style=False)
+        clean_yaml = dirty_yaml.replace("!!python/unicode","")
         with open(' %s.yaml' % self.command, 'w') as f:
             f.write(clean_yaml)
         print(clean_yaml)
